from odoo import models, fields

class Pricelist(models.Model):
    _name = "loempia.pricelist"
    _description = 'Apps Pricelist'

    def _default_currency_id(self):
        return self.env['res.currency'].search([('name', '=', 'EUR')])

    name = fields.Char('Pricelist Name', required=True, translate=True)
    price_per_batch = fields.Monetary(string="Price per batches of 100 lines of codes", currency_field='currency_id')
    currency_id = fields.Many2one('res.currency', 'Currency', required=True, default=_default_currency_id)
    country_group_ids = fields.One2many('res.country.group', 'loempia_pricelist_id', string='Country Groups')

    def _select_corresponding_pricelist(self, country_code):
        country_group = self.env['res.country.group'].search([('country_ids.code', '=', country_code)], limit=1)
        pricelist_id = self.get_default_pricelist()
        if country_group and country_group.loempia_pricelist_id:
            pricelist_id = country_group.loempia_pricelist_id
        return pricelist_id

    def get_default_pricelist(self):
        return self.env.ref('loempia.pricelist_default')

class ResCountryGroup(models.Model):
    _inherit = 'res.country.group'

    loempia_pricelist_id = fields.Many2one('loempia.pricelist', string='Pricelist')
